@@ -30,7 +30,6 @@
 
 #include <QMap>
 
-
 #include "kopetecontact.h"
 #include "kopetemessage.h"
 
@@ -38,7 +37,7 @@
 #include "gwfield.h"
 #include "gwmessagemanager.h"
 
-class KAction;
+class QAction;
 class KActionCollection;
 namespace Kopete { class Account; }
 class GroupWiseAccount;
@@ -89,23 +88,23 @@ public:
 	 */
 	void updateDetails( const GroupWise::ContactDetails & details );
 	
-	virtual bool isReachable();
+	bool isReachable() Q_DECL_OVERRIDE;
 	/**
 	 * Serialize the contact's data into a key-value map
 	 * suitable for writing to a file
 	 */
-    virtual void serialize(QMap< QString, QString >& serializedData,
-			QMap< QString, QString >& addressBookData);
+    void serialize(QMap< QString, QString >& serializedData,
+			QMap< QString, QString >& addressBookData) Q_DECL_OVERRIDE;
 	/**
 	 * Return the actions for this contact
 	 */
-	virtual QList<KAction *> *customContextMenuActions();
+	QList<QAction *> *customContextMenuActions() Q_DECL_OVERRIDE;
 	using Kopete::Contact::customContextMenuActions;
 	
 	/**
 	 * Returns a Kopete::ChatSession associated with this contact
 	 */
-	virtual Kopete::ChatSession *manager( Kopete::Contact::CanCreateFlags canCreate =  Kopete::Contact::CannotCreate );
+	Kopete::ChatSession *manager( Kopete::Contact::CanCreateFlags canCreate =  Kopete::Contact::CannotCreate ) Q_DECL_OVERRIDE;
 
 	/**
 	 * Access the contact's server properties
@@ -114,7 +113,7 @@ public:
 	/** 
 	 * Updates this contact's group membership and display name on the server
 	 */
-	void sync( unsigned int);
+	void sync( unsigned int) Q_DECL_OVERRIDE;
 	/**
 	 * Updates this contact's online status, including blocking status
 	 */
@@ -140,7 +139,7 @@ public:
 	 */
 	bool messageReceivedOffline() const;
 
-public slots:
+public Q_SLOTS:
 	/**
 	 * Transmits an outgoing message to the server 
 	 * Called when the chat window send button has been pressed
@@ -150,7 +149,7 @@ public slots:
 	/**
 	 * Delete this contact on the server
 	 */
-	virtual void deleteContact();
+	void deleteContact() Q_DECL_OVERRIDE;
 	/**
 	 * Called when the call to rename the contact on the server has completed
 	 */
@@ -159,11 +158,11 @@ public slots:
 protected:
 	// debug function to see what message managers we have on the server
 	void dumpManagers();
-protected slots:
+protected Q_SLOTS:
 	/**
 	 * Show the contact's properties
 	 */
-	void slotUserInfo();
+	void slotUserInfo() Q_DECL_OVERRIDE;
 	/**
 	 * Block or unblock the contact, toggle its current blocking state
 	 */
@@ -180,8 +179,8 @@ protected:
 	int m_sequence;
 	QString m_dn;
 	QString m_displayName;
-	KAction* m_actionPrefs;
-	KAction *m_actionBlock;
+	QAction * m_actionPrefs;
+	QAction *m_actionBlock;
 	// Novell Messenger Properties, as received by the server.  
 	// Unfortunately we don't know the domain of the set of keys, so they are not easily mappable to KopeteContactProperties
 	QMap< QString, QVariant > m_serverProperties;
